﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//////////////////////////////////////////////////////////////////
//【敵（サソリ）のコントロールに使用するクラス】
// 敵（サソリ）を横方向に動かす、壁に衝突したら反転させる処理を実行
//////////////////////////////////////////////////////////////////
public class EnemyController : MonoBehaviour
{
    /////////////////////////////////
    // 【変数の設定】
    /////////////////////////////////

    //【定数の設定】（レベル設計で変更可能）
    const float WALK_FORCE = 7;  // 横に進む時にかける力の強さ
    const float MAX_WALK_SPEED = 1;  // 横に進む速度の最大値

    //【Unity Editorから設定するPublic変数】
    public Rigidbody2D rigidBody;  // Rigidbody2Dコンポーネントの変数や関数の呼び出し用

    //【このプログラム内で使用するPrivate変数】
    private GameManager class_GameManager;  // GameManagerの関数呼び出し用
    private int direction = 1;  // 敵（サソリ）の横向きの方向を示すdirection変数、初期値を右
    // （右方向を向いている場合１、左方向を向いている場合ー１）
    private int stopCount = 0;  // 壁にぶつかった場合、数フレーム後に反転を行うためのカウント用変数


    /////////////////////////////////
    // 【関数の設定】
    /////////////////////////////////

    //【ゲーム開始時に１回だけ動く関数】
    //（Unityの標準関数）
    void Start()
    {
        // Scene上のGameManagerゲームオブジェクトを取得して
        // GameManagerに付いているGameManagerコンポーネントを取得
        //（Playerの様にPublic変数にすると敵をScene上に置く際に毎回
        // GameManagerの関連付けをする必要があるため自動取得させる）
        class_GameManager = GameObject.Find("GameManager").GetComponent<GameManager>();
    }


    //【毎フレームに１度動く関数】
    //（Unityの標準関数）
    void Update()
    {
        // GameManagerのOnGet_StopGame関数（ゲーム一時停止中かを返す）を呼び出しTrueの場合
        if (class_GameManager.OnGet_StopGame())
        {
            // Playerのスピードをゼロにして停止させる
            rigidBody.velocity = Vector3.zero;
            // このフレームではこれ以下の処理は実行させない
            return;
        }

        // speedx変数に敵（サソリ）の横方向のスピード（絶対値）を代入
        float speedx = Mathf.Abs(rigidBody.velocity.x);

        // 横方向のスピードがMAX_WALK_SPEEDのスピードより小さい場合
        if (speedx < MAX_WALK_SPEED)
        {
            // 敵（サソリ）にdirection変数が１の場合は右に、ー１の場合は左に力をかける
            rigidBody.AddForce(transform.right * direction * WALK_FORCE);
        }

        // direction変数が１の場合は右に、ー１の場合は左に、敵（サソリ）のSprite（絵）の向きを変える
        transform.localScale = new Vector3(0.1f * direction, 0.1f, 1);

        // 横方向のスピードがゼロの場合
        if (rigidBody.velocity.x == 0)
        {
            // ゲーム開始時や壁にぶつかり反転した際はスピードがゼロなので、
            // 少し待つ機能がないと永遠に反転を繰り返してしまう。
            stopCount++;
            // スピードがゼロの状態が一定フレーム続いたら
            if (stopCount >= 10)
            {
                // direction変数にー１をかけて方向を逆にする
                direction = direction * -1;
                // スピードがゼロの状態をカウントするカウンターをゼロリセットする
                stopCount = 0;
            }
        }
    }
}
