﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

using UnityEngine.SceneManagement;  // シーンの切り替えに使用

//////////////////////////////////////////////////////////////////
//【ゲーム全体の管理に使用するクラス】
// ゲームオーバーやコンティニュー処理を実行
//////////////////////////////////////////////////////////////////
public class GameManager : MonoBehaviour
{
    /////////////////////////////////
    // 【変数の設定】
    /////////////////////////////////

    //【定数の設定】（レベル設計で変更可能）
    const float CONTINUE_LV1 = 7;  // コンティニュー用の１つめの通過ポイント
    const float CONTINUE_LV2 = 28;  // コンティニュー用の２つめの通過ポイント

    //【Unity Editorから設定するPublic変数】
    public GameObject text_GameOver;  // UIにGame Overを表示するテキスト
    public GameObject player;  // Scene上のPlayerゲームオブジェクト

    //【このプログラム内で使用するPrivate変数】
    private bool stopGame = false;  // ゲームがストップしている場合 true


    /////////////////////////////////
    // 【関数の設定】
    /////////////////////////////////

    //【ゲーム開始時に１回だけ動く関数】
    //（Unityの標準関数）
    void Start()
    {
        // 保存してあるコンティニュー用レベルを取得する
        switch (PlayerPrefs.GetInt("CONT_LV", 1))
        {
            // 保存してあるコンティニュー用レベルが１の場合
            case 1:
                // Playerを指定位置に移動させる
                player.transform.position = new Vector3(0, -4, 0);
                break;

            // 保存してあるコンティニュー用レベルが２の場合
            case 2:
                // Playerを指定位置に移動させる
                player.transform.position = new Vector3(0, CONTINUE_LV1 + 1, 0);
                break;

            // 保存してあるコンティニュー用レベルが３の場合
            case 3:
                // Playerを指定位置に移動させる
                player.transform.position = new Vector3(0, CONTINUE_LV2 + 1, 0);
                break;
        }
    }


    //【他のプログラムからゲームがストップしているか確認する関数】
    public bool OnGet_StopGame()
    {
        // stopGame変数の値を返す（ゲームがストップしている場合 true）
        return stopGame;
    }


    //【ゲームオーバー時に他のプログラムから呼ばれるゲームオーバ処理の関数】
    public void GameOver()
    {
        // UIにGame Overのテキストを表示
        text_GameOver.SetActive(true);

        // GameをStopさせる
        stopGame = true;

        int continue_Level = 1; // コンティニュー用レベル（初期値は１）
        // ゲームオーバー時にPlayerがコンティニュー用の２つめの通過ポイントより上にいる場合、コンティニュー用レベル３
        if (player.transform.position.y > CONTINUE_LV2) continue_Level = 3;
        // ゲームオーバー時にPlayerがコンティニュー用の１つめの通過ポイントより上にいる場合、コンティニュー用レベル２
        else if (player.transform.position.y > CONTINUE_LV1) continue_Level = 2;
        // コンティニュー用レベルを保存する
        PlayerPrefs.SetInt("CONT_LV", continue_Level);

        // Playerを消す
        player.SetActive(false);
    }


    //【リスタート用ボタンを押された際の処理関数】
    public void OnClickRestart()
    {
        // コンティニュー用レベルに１を保存する
        PlayerPrefs.SetInt("CONT_LV", 1);

        // GameMainシーンを呼び出す
        SceneManager.LoadScene("GameMain");
    }


    //【コンティニュー用ボタンを押された際の処理関数】
    public void OnClickContinue()
    {
        // GameMainシーンを呼び出す
        SceneManager.LoadScene("GameMain");
    }
}
